@@ -316,6 +316,8 @@ class Client(object):
             finally:
                 self.sock = None
 
+    disconnect_all = close
+
     def set(self, key, value, expire=0, noreply=None, flags=None):
         """
         The memcached "set" command.
@@ -636,7 +638,7 @@ class Client(object):
 
         Args:
           key: str, see class docs for details.
-          value: int, the amount by which to increment the value.
+          value: int, the amount by which to decrement the value.
           noreply: optional bool, False to wait for the reply (the default).
 
         Returns:
@@ -1075,6 +1077,8 @@ class PooledClient(object):
     def close(self):
         self.client_pool.clear()
 
+    disconnect_all = close
+
     def set(self, key, value, expire=0, noreply=None, flags=None):
         with self.client_pool.get_and_release(destroy_on_fail=True) as client:
             return client.set(key, value, expire=expire, noreply=noreply,
@@ -1082,9 +1086,8 @@ class PooledClient(object):
 
     def set_many(self, values, expire=0, noreply=None, flags=None):
         with self.client_pool.get_and_release(destroy_on_fail=True) as client:
-            failed = client.set_many(values, expire=expire, noreply=noreply,
-                                     flags=flags)
-            return failed
+            return client.set_many(values, expire=expire, noreply=noreply,
+                                   flags=flags)
 
     set_multi = set_many
 
